.. Elephantoplasty documentation master file, created by
   sphinx-quickstart on Wed Jul 27 17:33:32 2011.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

.. highlight:: python
    :linenothreshold: 5


Welcome to Elephantoplasty's documentation!
===========================================

Contents:

.. toctree::
    :maxdepth: 2

    introduction
    basics/index
    advanced/index
    api/index

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

